@@ -1,19 +1,19 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "smtpconfigdialog.h"
 
+#include "smtpconfigwidget.h"
 #include "transport.h"
 #include "transportmanager.h"
 #include "transporttype.h"
-#include "smtpconfigwidget.h"
 
 #include <QDialogButtonBox>
-#include <QVBoxLayout>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace MailTransport;
 
@@ -22,7 +22,7 @@ SmtpConfigDialog::SmtpConfigDialog(Transport *transport, QWidget *parent)
 {
     Q_ASSERT(transport);
     mTransport = transport;
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mConfigWidget = new SMTPConfigWidget(transport, this);
     mConfigWidget->setObjectName(QStringLiteral("smtpconfigwidget"));
     mainLayout->addWidget(mConfigWidget);
