@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,18 +8,18 @@
 #include "../src/kmailtransport/widgets/addtransportdialogng.h"
 
 #include <QApplication>
-#include <QStandardPaths>
 #include <QHBoxLayout>
 #include <QPushButton>
+#include <QStandardPaths>
 
 AddTransportDialogNG_gui::AddTransportDialogNG_gui(QWidget *parent)
     : QWidget(parent)
 {
-    auto *layout = new QHBoxLayout(this);
+    auto layout = new QHBoxLayout(this);
     QPushButton *button = new QPushButton(QStringLiteral("Add transport"));
     layout->addWidget(button);
     connect(button, &QPushButton::clicked, this, [this] {
-        auto *dlg = new MailTransport::AddTransportDialogNG(this);
+        auto dlg = new MailTransport::AddTransportDialogNG(this);
         dlg->exec();
         delete dlg;
     });
@@ -30,7 +30,7 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("addtransportnewng"));
     QStandardPaths::setTestModeEnabled(true);
-    auto *t = new AddTransportDialogNG_gui();
+    auto t = new AddTransportDialogNG_gui();
     t->show();
     app.exec();
     delete t;
