@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2006-2007 Volker Krause <vkrause@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,7 +14,8 @@
 
 class TransportComboBoxPrivate;
 
-namespace MailTransport {
+namespace MailTransport
+{
 /**
   A combo-box for selecting a mail transport.
   It is updated automatically when transports are added, changed, or removed.
@@ -41,7 +42,7 @@ public:
       @param transportId The transport identifier.
       @return return true if we success to find transportId
     */
-    Q_REQUIRED_RESULT bool setCurrentTransport(int transportId);
+    bool setCurrentTransport(int transportId);
 
     /**
       Returns the type of the selected transport.
