@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <MailTransport/TransportAbstractPlugin>
 #include <QVariant>
-namespace Akonadi {
+namespace Akonadi
+{
 class AgentType;
 }
 
@@ -17,8 +18,7 @@ class AkonadiMailTransportPlugin : public MailTransport::TransportAbstractPlugin
 {
     Q_OBJECT
 public:
-    explicit AkonadiMailTransportPlugin(QObject *parent = nullptr, const QList<QVariant> & = {
-    });
+    explicit AkonadiMailTransportPlugin(QObject *parent = nullptr, const QList<QVariant> & = {});
     ~AkonadiMailTransportPlugin() override;
 
     Q_REQUIRED_RESULT QVector<MailTransport::TransportAbstractPluginInfo> names() const override;
